/*
 * Sangoma Transcoder Library
 *
 * Nenad Corbic <ncorbic@sangoma.com>
 * Moises Silva <moy@sangoma.com>
 *
 * Copyright (C) 2010 Sangoma Technologies
 *
 * Redistribution and use is permitted only in binary forms without
 * modification and provided that the following conditions are met:
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of the original author; nor the names of any contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Contributors:
 *
 */
#ifndef _LIB_SANGOMA_TRANSCODE_UTILS_
#define _LIB_SANGOMA_TRANSCODE_UTILS_

#include "sng_tc_if.h"

/*!
  \enum SNGTC_LOGLEVEL_DEBUG
  \enum SNGTC_LOGLEVEL_WARN
  \enum SNGTC_LOGLEVEL_INFO
  \enum SNGTC_LOGLEVEL_STATS
  \enum SNGTC_LOGLEVEL_ERROR
  \enum SNGTC_LOGLEVEL_CRIT
 */
enum {
	SNGTC_LOGLEVEL_DEBUG = 1,
	SNGTC_LOGLEVEL_STATS,
	SNGTC_LOGLEVEL_WARN,
	SNGTC_LOGLEVEL_INFO,
	SNGTC_LOGLEVEL_ERROR,
	SNGTC_LOGLEVEL_CRIT,
	SNGTC_LOGLEVEL_PUBLIC = 100,
};

#if 1

extern sngtc_log_func_t _SNGTC_API sngtc_log_func;

#define sngtc_print(level,fmt,...) if (sngtc_log_func) sngtc_log_func(level,fmt,##__VA_ARGS__);
#define SNGTC_DEBUG(a,...) 		sngtc_print(SNGTC_LOGLEVEL_DEBUG,a,##__VA_ARGS__)
#define SNGTC_WARN(a,...) 		sngtc_print(SNGTC_LOGLEVEL_WARN,a,##__VA_ARGS__)
#define SNGTC_INFO(a,...) 		sngtc_print(SNGTC_LOGLEVEL_INFO,a,##__VA_ARGS__)
#define SNGTC_STATS(a,...) 		sngtc_print(SNGTC_LOGLEVEL_STATS,a,##__VA_ARGS__)
#define SNGTC_ERROR(a,...)		sngtc_print(SNGTC_LOGLEVEL_ERROR,a,##__VA_ARGS__)
#define SNGTC_CRIT(a,...) 		sngtc_print(SNGTC_LOGLEVEL_CRIT,a,##__VA_ARGS__)
#define SNGTC_TEST(a,...)
#else
#define SNGTC_PRINT printf
#define SNGTC_DEBUG printf
#define SNGTC_WARN  printf
#define SNGTC_INFO  printf
#define SNGTC_STATS printf
#define SNGTC_ERROR printf
#define SNGTC_CRIT printf
#define SNGTC_TEST printf
#endif




#define SNGTC_NIPV4(addr) \
	((unsigned char *)&addr)[3], \
	((unsigned char *)&addr)[2], \
	((unsigned char *)&addr)[1], \
	((unsigned char *)&addr)[0]

#define SNGTC_NIPV4_FMT "%u.%u.%u.%u"


#define SNGTC_LOGLEVEL_DECODE(level) \
		((level==SNGTC_LOGLEVEL_DEBUG) ? "SNGMP_DEBUG" : \
		(level==SNGTC_LOGLEVEL_WARN) ? "SNGMP_WARN" : \
		(level==SNGTC_LOGLEVEL_INFO) ? "SNGMP_INFO" : \
		(level==SNGTC_LOGLEVEL_STATS) ? "SNGMP_STATS" : \
		(level==SNGTC_LOGLEVEL_ERROR) ? "SNGMP_ERROR" : \
		(level==SNGTC_LOGLEVEL_CRIT) ? "SNGMP_CRIT" : "Unkown")
		

static SNG_INLINE int sngtc_codec_ipv4_str_hex(const char *ip_str, uint32_t *ip_addr)
{
	char t_ip_str[50];
	char *p;
	uint32_t temp;
	char cnt=3;
#ifndef WIN32
	char *saveptr;
#endif
	*ip_addr=0;

	if (strlen(ip_str) > 15) {
		return 1;
	}

	sngtc_snprintf(t_ip_str, sizeof(t_ip_str), "%s",ip_str);

	p = sngtc_strtok_r(t_ip_str, ".", &saveptr);
	while (p != NULL) {

		if (atoi(p) > 255) {
			SNGTC_ERROR( "%s(): Error: Invalid IP %s\n",__FUNCTION__,ip_str);
			return 1;
		}
	
		temp = atoi(p);
		temp= temp&0xFF;

		//SNGTC_DEBUG("GOT IP NIBBLE 0x%02X Shifting by %i Shift=0x%08X\n",temp,8*cnt, (temp<<(8*cnt)));
		p=sngtc_strtok_r(NULL, ".", &saveptr);

		*ip_addr |= (temp<<(8*cnt));

		if (cnt > 0) {
			cnt--;
		}
	}

	if (cnt != 0) { 
		SNGTC_ERROR("libsangoma_codec_ipv4_str_hex(): CNT ERROR IP=%s = IP=0x%08X cnt=%i p=%s tip=%s\n",
					ip_str, *ip_addr, cnt, p, t_ip_str);
		return 1;
	}

	return 0;
}


static SNG_INLINE int sngtc_codec_ipv4_hex_to_str(uint32_t ip_addr, char *ip_str)
{
	sprintf(ip_str,"%d.%d.%d.%d",
			(ip_addr>>24)&0xFF,
			(ip_addr>>16)&0xFF,
			(ip_addr>>8)&0xFF,
			(ip_addr)&0xFF);


	return 0;
}

enum {
	SNGTC_MODE_LIBRARY,
	SNGTC_MODE_SOAP_CLIENT,
	SNGTC_MODE_SOAP_SERVER
};


#endif

