/*
 * Sangoma Media Processing Library
 *
 * Moises Silva <moy@sangoma.com>
 *
 * Copyright (C) 2011 Sangoma Technologies
 *
 * Redistribution and use is permitted only in binary forms without
 * modification and provided that the following conditions are met:
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of the original author; nor the names of any contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Contributors:
 *
 */

#ifndef _SNGMP_DECLARE_H_
#define _SNGMP_DECLARE_H_

#include <stdio.h>
#include <stdint.h>

#ifdef __cplusplus
#define SNGMP_BEGIN_EXTERN_C extern "C" {
#define SNGMP_END_EXTERN_C }
#else
#define SNGMP_BEGIN_EXTERN_C 
#define SNGMP_END_EXTERN_C 
#endif

SNGMP_BEGIN_EXTERN_C

typedef enum sngmp_result {
	/*! API executed with success */
	SNGMP_SUCCESS = 0,
	/*! Generic error, try using a more specific one if possible */
	SNGMP_ERROR = 1,
	/*! Invalid argument provided */
	SNGMP_EINVAL = 2,
	/*! Out of memory */
	SNGMP_ENOMEM = 3,
	/*! Resource busy */
	SNGMP_EBUSY = 4,
} sngmp_result_t;

typedef enum {
	SNGMP_FALSE = 0,
	SNGMP_TRUE
} sngmp_bool_t;

/*! \brief Socket address */
typedef struct sngmp_sockaddr_s sngmp_sockaddr_t;

/*! \brief IP port*/
typedef uint16_t sngmp_ip_port_t;

/*! \brief Supported media types */
typedef enum {
	SNGMP_MEDIA_AUDIO,
	SNGMP_MEDIA_VIDEO
} sngmp_media_type_t;

/*! \brief Media description */
typedef struct sngmp_media_description_s sngmp_media_description_t;

/*! \brief Media Processing Module */
typedef struct sngmp_module_s sngmp_module_t;

/*! \brief Generic flags */
typedef uint64_t sngmp_flags_t;

typedef size_t sngmp_size_t;

#define SNGMP_DECLARE(return_value) return_value 
#define SNGMP_DECLARE_DATA 

SNGMP_END_EXTERN_C

#endif /* endif defined _SNGMP_DECLARE_H_ */

