/*
 * Sangoma Media Processing Library
 *
 * Moises Silva <moy@sangoma.com>
 *
 * Copyright (C) 2011 Sangoma Technologies
 *
 * Redistribution and use is permitted only in binary forms without
 * modification and provided that the following conditions are met:
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of the original author; nor the names of any contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Contributors:
 *
 */

#ifndef _SNGMP_LOG_H_
#define _SNGMP_LOG_H_

#include "sngmp_declare.h"

SNGMP_BEGIN_EXTERN_C

typedef enum {
	SNGMP_LOG_LEVEL_CRIT     = 1,
	SNGMP_LOG_LEVEL_ERROR    = 2,
	SNGMP_LOG_LEVEL_WARNING  = 3,
	SNGMP_LOG_LEVEL_NOTICE   = 4,
	SNGMP_LOG_LEVEL_DEBUG    = 5,
} sngmp_log_level_t;
SNGMP_DECLARE_DATA extern const char *SNGMP_LOG_LEVEL_NAMES[SNGMP_LOG_LEVEL_DEBUG];

typedef void (*sngmp_logging_func_t)(const char *file, const char *function, unsigned int line, sngmp_log_level_t level, const char *fmt, ...);

SNGMP_DECLARE_DATA extern sngmp_logging_func_t sngmp_log;

/* default first args to log functions */
#define SNGMP_LOG_PRE __FILE__, __FUNCTION__, __LINE__

#define SNGMP_LOG_CRIT SNGMP_LOG_PRE, SNGMP_LOG_LEVEL_CRIT
#define SNGMP_LOG_ERROR SNGMP_LOG_PRE, SNGMP_LOG_LEVEL_ERROR
#define SNGMP_LOG_WARNING SNGMP_LOG_PRE, SNGMP_LOG_LEVEL_WARNING
#define SNGMP_LOG_NOTICE SNGMP_LOG_PRE, SNGMP_LOG_LEVEL_NOTICE
#define SNGMP_LOG_DEBUG SNGMP_LOG_PRE, SNGMP_LOG_LEVEL_DEBUG

SNGMP_DECLARE(void) sngmp_log_set_logger(sngmp_logging_func_t logger);

SNGMP_END_EXTERN_C

#endif /* endif defined _SNGMP_LOG_H_ */

