/*
 * Sangoma Media Processing Library
 *
 * Moises Silva <moy@sangoma.com>
 *
 * Copyright (C) 2011 Sangoma Technologies
 *
 * Redistribution and use is permitted only in binary forms without
 * modification and provided that the following conditions are met:
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of the original author; nor the names of any contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Contributors:
 *
 */

#ifndef _SNGMP_OS_H_
#define _SNGMP_OS_H_

#include <stdio.h>
#include "sngmp_declare.h"
#include "sngmp_log.h"

SNGMP_BEGIN_EXTERN_C 

#ifdef _WIN32
#ifndef __inline__
#define __inline__ __inline
#endif
#endif

/*!
  \brief Allocate uninitialized memory
  \param chunksize the chunk size
*/
#define sngmp_malloc(chunksize) sngmp_global_memory_handler.malloc(sngmp_global_memory_handler.pool, chunksize)

/*!
  \brief Reallocates memory
  \param buff the buffer
  \param chunksize the chunk size
*/
#define sngmp_realloc(buff, chunksize) sngmp_global_memory_handler.realloc(sngmp_global_memory_handler.pool, buff, chunksize)

/*!
  \brief Allocate initialized memory
  \param chunksize the chunk size
*/
#define sngmp_calloc(elements, chunksize) sngmp_global_memory_handler.calloc(sngmp_global_memory_handler.pool, elements, chunksize)

/*!
  \brief Free chunk of memory
  \param chunksize the chunk size
*/
#define sngmp_free(chunk) sngmp_global_memory_handler.free(sngmp_global_memory_handler.pool, chunk)

/*!
  \brief Free a pointer and set it to NULL unless it already is NULL
  \param it the pointer
*/
#define sngmp_safe_free(it) if (it) { sngmp_free(it); it = NULL; }

/*! \brief strncpy into a fixed size buffer */
#define sngmp_set_string(x,y) strncpy(x, y, sizeof(x)-1)

static __inline__ void sngmp_abort(void)
{
#ifdef __cplusplus
	::abort();
#else
	abort();
#endif
}

SNGMP_END_EXTERN_C

#endif /* endif defined _SNGMP_OS_H_ */

